==> blapsr_0.5.5.tar.gz: blapsr/README.md <==
# Approximate Bayesian inference with blapsr #

&nbsp; 

<p style="text-align:center;">
<img src="https://static.wixstatic.com/media/78f262_b02ebe363df6456a8ed2d70606b1417c~mv2.png" width = "200" height="215">
</p>

&nbsp; 

![GitHub followers](https://img.shields.io/github/followers/oswaldogressani?style=social) ![GitHub top
language](https://img.shields.io/github/languages/top/oswaldogressani/blapsr?label=R) ![GitHub
reposize](https://img.shields.io/github/repo-size/oswaldogressani/blapsr?label=Repo%20size) ![GitHub All Releases](https://img.shields.io/github/downloads/oswaldogressani/blapsr/total?label=Downloads) ![CRAN/METACRAN](https://img.shields.io/cran/l/blapsr?color=purple&label=License) ![CRAN/METACRAN](https://img.shields.io/cran/v/blapsr?color=gold&label=CRAN)

&nbsp;

### Purpose ###
<hr />

The blapsr package consists in a set of routines that can be used for analysis
in survival models and (generalized) additive models. The methodology is based 
on the combination of Bayesian P-splines for flexible estimation of smooth 
functions and Laplace approximations to (selected) posterior distributions.

### Version ###
<hr />
First version (0.5.1) was published on CRAN 2020-07-13. <br>
This is version 0.5.5.

### Website ###
<hr />

A website is dedicated to the package: www.blapsr-project.org. The link to the
CRAN page is https://cran.r-project.org/package=blapsr .

### Special thanks ###
<hr />

This package was developed during a PhD thesis at Université catholique de Louvain (Belgium) that was funded in part by the Actions de Recherche Concertées
(ARC 11/16-039) grant and another grant obtained from the Luxembourgish Ministry 
of higher education.

We are grateful to Vincent Bremhorst for providing the function on which the 
simcuredata.R routine is based. The latter is used for generating survival times
in the promotion time cure model (Bremhorst and Lambert, 2016).

==> blapsr_0.6.1.tar.gz: blapsr/README.md <==
# Approximate Bayesian inference with blapsr #

&nbsp; 

<p style="text-align:center;">
<img src="https://static.wixstatic.com/media/78f262_b02ebe363df6456a8ed2d70606b1417c~mv2.png" width = "200" height="215">
</p>

&nbsp; 

![GitHub followers](https://img.shields.io/github/followers/oswaldogressani?style=social) ![GitHub top
language](https://img.shields.io/github/languages/top/oswaldogressani/blapsr?label=R) ![GitHub
reposize](https://img.shields.io/github/repo-size/oswaldogressani/blapsr?label=Repo%20size) ![GitHub All Releases](https://img.shields.io/github/downloads/oswaldogressani/blapsr/total?label=Downloads) ![CRAN/METACRAN](https://img.shields.io/cran/l/blapsr?color=purple&label=License) ![CRAN/METACRAN](https://img.shields.io/cran/v/blapsr?color=gold&label=CRAN)

&nbsp;

### Purpose ###
<hr />

The blapsr package consists in a set of routines that can be used for analysis
in survival models and (generalized) additive models. The methodology is based 
on the combination of Bayesian P-splines for flexible estimation of smooth 
functions and Laplace approximations to (selected) posterior distributions.

### Version ###
<hr />
First version (0.5.1) was published on CRAN 2020-07-13. <br>
This is version 0.6.1 (submitted to CRAN on 2022-08-20).

### Website ###
<hr />

A website is dedicated to the package: https://www.blapsr-project.org. The link to the
CRAN page is https://cran.r-project.org/package=blapsr .

### Special thanks ###
<hr />

This package was developed during a PhD thesis at Université catholique de Louvain (Belgium) that was funded in part by the Actions de Recherche Concertées
(ARC 11/16-039) grant and another grant obtained from the Luxembourgish Ministry 
of higher education.

We are grateful to Vincent Bremhorst for providing the function on which the 
simcuredata.R routine is based. The latter is used for generating survival times
in the promotion time cure model (Bremhorst and Lambert, 2016).
